@@ -10,6 +10,7 @@
 #               2010/06/18 - PH Support variable-length CustomPictureStyle data
 #               2010/09/14 - PH Added r/w support for XMP in VRD
 #               2015/05/16 - PH Added DR4 support (DPP 4.1.50.0)
+#               2018/03/13 - PH Update to DPP 4.8.20
 #
 # References:   1) Bogdan private communication (Canon DPP v3.4.1.1)
 #               2) Gert Kello private communiation (DPP 3.8)
@@ -22,7 +23,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Canon;
 
-$VERSION = '1.29';
+$VERSION = '1.32';
 
 sub ProcessCanonVRD($$;$);
 sub WriteCanonVRD($$;$);
@@ -1144,6 +1145,8 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     0x20600 => 'LuminanceNoiseReduction',
     0x20601 => 'ChrominanceNoiseReduction',
     # 0x20650 - fmt=9: 0 (JPG images)
+    0x20670 => 'ColorMoireReduction',
+   '0x20670.0' => { Name => 'ColorMoireReductionOn', %noYes },
     0x20701 => {
         Name => 'ShootingDistance',
         Notes => '100% = infinity',
@@ -1195,13 +1198,14 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     },
     # 0x20800 - fmt=1: 0
     # 0x20801 - fmt=1: 0
+    0x2070b => { Name => 'DiffractionCorrectionOn', %noYes },
     0x20900 => 'ColorHue',
     0x20901 => 'SaturationAdj',
     0x20910 => 'RedHSL',
     0x20911 => 'OrangeHSL',
-    0x20912 => 'GreenHSL',
-    0x20913 => 'AquaHSL',
-    0x20914 => 'BlueHSL',
+    0x20912 => 'YellowHSL',
+    0x20913 => 'GreenHSL',
+    0x20914 => 'AquaHSL',
     0x20915 => 'BlueHSL',
     0x20916 => 'PurpleHSL',
     0x20917 => 'MagentaHSL',
@@ -1280,7 +1284,7 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
         Name => 'DR4CameraModel',
         Writable => 'int32u',
         PrintHex => 1,
-        SeparateTable => 'Canon CameraModelID',
+        SeparateTable => 'Canon CanonModelID',
         PrintConv => \%Image::ExifTool::Canon::canonModelID,
     },
     # 4 - value: 3
@@ -1517,6 +1521,7 @@ sub ProcessEditData($$$)
         # make a copy for editing in place
         my $buff = substr($$dataPt, $pos, $dirLen);
         $dataPt = $$dirInfo{DataPt} = \$buff;
+        $dataPos += $pos;
         $pos = $$dirInfo{DirStart} = 0;
     }
     my $dirEnd = $pos + $dirLen;
