@@ -10,6 +10,7 @@
 #               3) http://developer.apple.com/documentation/GraphicsImaging/Reference/ColorSync_Manager/ColorSync_Manager.pdf
 #               4) http://www.color.org/privatetag2007-01.pdf
 #               5) http://www.color.org/icc_specs2.xalter (approved revisions, 2010-07-16)
+#               6) Eef Vreeland private communication
 #
 # Notes:        The ICC profile information is different: the format of each
 #               tag is embedded in the information instead of in the directory
@@ -23,7 +24,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.30';
+$VERSION = '1.35';
 
 sub ProcessICC($$);
 sub ProcessICC_Profile($$$);
@@ -52,6 +53,283 @@ my %profileClass = (
     nmcl => 'NamedColor Profile',
     nkpf => 'Nikon Input Device Profile (NON-STANDARD!)', # (written by Nikon utilities)
 );
+my %manuSig = ( #6
+    'NONE' => 'none',
+    'none' => 'none', #PH
+    ''     => '', #PH
+    '4d2p' => 'Erdt Systems GmbH & Co KG',
+    'AAMA' => 'Aamazing Technologies, Inc.',
+    'ACER' => 'Acer Peripherals',
+    'ACLT' => 'Acolyte Color Research',
+    'ACTI' => 'Actix Sytems, Inc.',
+    'ADAR' => 'Adara Technology, Inc.',
+    'ADBE' => 'Adobe Systems Inc.',
+    'ADI ' => 'ADI Systems, Inc.',
+    'AGFA' => 'Agfa Graphics N.V.',
+    'ALMD' => 'Alps Electric USA, Inc.',
+    'ALPS' => 'Alps Electric USA, Inc.',
+    'ALWN' => 'Alwan Color Expertise',
+    'AMTI' => 'Amiable Technologies, Inc.',
+    'AOC ' => 'AOC International (U.S.A), Ltd.',
+    'APAG' => 'Apago',
+    'APPL' => 'Apple Computer Inc.',
+    'appl' => 'Apple Computer Inc.',
+    'AST ' => 'AST',
+    'AT&T' => 'AT&T Computer Systems',
+    'BAEL' => 'BARBIERI electronic',
+    'berg' => 'bergdesign incorporated',
+    'bICC' => 'basICColor GmbH',
+    'BRCO' => 'Barco NV',
+    'BRKP' => 'Breakpoint Pty Limited',
+    'BROT' => 'Brother Industries, LTD',
+    'BULL' => 'Bull',
+    'BUS ' => 'Bus Computer Systems',
+    'C-IT' => 'C-Itoh',
+    'CAMR' => 'Intel Corporation',
+    'CANO' => 'Canon, Inc. (Canon Development Americas, Inc.)',
+    'CARR' => 'Carroll Touch',
+    'CASI' => 'Casio Computer Co., Ltd.',
+    'CBUS' => 'Colorbus PL',
+    'CEL ' => 'Crossfield',
+    'CELx' => 'Crossfield',
+    'ceyd' => 'Integrated Color Solutions, Inc.',
+    'CGS ' => 'CGS Publishing Technologies International GmbH',
+    'CHM ' => 'Rochester Robotics',
+    'CIGL' => 'Colour Imaging Group, London',
+    'CITI' => 'Citizen',
+    'CL00' => 'Candela, Ltd.',
+    'CLIQ' => 'Color IQ',
+    'clsp' => 'MacDermid ColorSpan, Inc.',
+    'CMCO' => 'Chromaco, Inc.',
+    'CMiX' => 'CHROMiX',
+    'COLO' => 'Colorgraphic Communications Corporation',
+    'COMP' => 'COMPAQ Computer Corporation',
+    'COMp' => 'Compeq USA/Focus Technology',
+    'CONR' => 'Conrac Display Products',
+    'CORD' => 'Cordata Technologies, Inc.',
+    'CPQ ' => 'Compaq Computer Corporation',
+    'CPRO' => 'ColorPro',
+    'CRN ' => 'Cornerstone',
+    'CTX ' => 'CTX International, Inc.',
+    'CVIS' => 'ColorVision',
+    'CWC ' => 'Fujitsu Laboratories, Ltd.',
+    'DARI' => 'Darius Technology, Ltd.',
+    'DATA' => 'Dataproducts',
+    'DCP ' => 'Dry Creek Photo',
+    'DCRC' => 'Digital Contents Resource Center, Chung-Ang University',
+    'DELL' => 'Dell Computer Corporation',
+    'DIC ' => 'Dainippon Ink and Chemicals',
+    'DICO' => 'Diconix',
+    'DIGI' => 'Digital',
+    'DL&C' => 'Digital Light & Color',
+    'DPLG' => 'Doppelganger, LLC',
+    'DS  ' => 'Dainippon Screen',
+    'ds  ' => 'Dainippon Screen',
+    'DSOL' => 'DOOSOL',
+    'DUPN' => 'DuPont',
+    'dupn' => 'DuPont',
+    'Eizo' => 'EIZO NANAO CORPORATION',
+    'EPSO' => 'Epson',
+    'ESKO' => 'Esko-Graphics',
+    'ETRI' => 'Electronics and Telecommunications Research Institute',
+    'EVER' => 'Everex Systems, Inc.',
+    'EXAC' => 'ExactCODE GmbH',
+    'FALC' => 'Falco Data Products, Inc.',
+    'FF  ' => 'Fuji Photo Film Co.,LTD',
+    'FFEI' => 'FujiFilm Electronic Imaging, Ltd.',
+    'ffei' => 'FujiFilm Electronic Imaging, Ltd.',
+    'flux' => 'FluxData Corporation',
+    'FNRD' => 'fnord software',
+    'FORA' => 'Fora, Inc.',
+    'FORE' => 'Forefront Technology Corporation',
+    'FP  ' => 'Fujitsu',
+    'FPA ' => 'WayTech Development, Inc.',
+    'FUJI' => 'Fujitsu',
+    'FX  ' => 'Fuji Xerox Co., Ltd.',
+    'GCC ' => 'GCC Technologies, Inc.',
+    'GGSL' => 'Global Graphics Software Limited',
+    'GMB ' => 'Gretagmacbeth',
+    'GMG ' => 'GMG GmbH & Co. KG',
+    'GOLD' => 'GoldStar Technology, Inc.',
+    'GOOG' => 'Google', #PH
+    'GPRT' => 'Giantprint Pty Ltd',
+    'GTMB' => 'Gretagmacbeth',
+    'GVC ' => 'WayTech Development, Inc.',
+    'GW2K' => 'Sony Corporation',
+    'HCI ' => 'HCI',
+    'HDM ' => 'Heidelberger Druckmaschinen AG',
+    'HERM' => 'Hermes',
+    'HITA' => 'Hitachi America, Ltd.',
+    'HiTi' => 'HiTi Digital, Inc.',
+    'HP  ' => 'Hewlett-Packard',
+    'HTC ' => 'Hitachi, Ltd.',
+    'IBM ' => 'IBM Corporation',
+    'IDNT' => 'Scitex Corporation, Ltd.',
+    'Idnt' => 'Scitex Corporation, Ltd.',
+    'IEC ' => 'Hewlett-Packard',
+    'IIYA' => 'Iiyama North America, Inc.',
+    'IKEG' => 'Ikegami Electronics, Inc.',
+    'IMAG' => 'Image Systems Corporation',
+    'IMI ' => 'Ingram Micro, Inc.',
+    'Inca' => 'Inca Digital Printers Ltd.',
+    'INTC' => 'Intel Corporation',
+    'INTL' => 'N/A (INTL)',
+    'INTR' => 'Intra Electronics USA, Inc.',
+    'IOCO' => 'Iocomm International Technology Corporation',
+    'IPS ' => 'InfoPrint Solutions Company',
+    'IRIS' => 'Scitex Corporation, Ltd.',
+    'Iris' => 'Scitex Corporation, Ltd.',
+    'iris' => 'Scitex Corporation, Ltd.',
+    'ISL ' => 'Ichikawa Soft Laboratory',
+    'ITNL' => 'N/A (ITNL)',
+    'IVM ' => 'IVM',
+    'IWAT' => 'Iwatsu Electric Co., Ltd.',
+    'JPEG' => 'Joint Photographic Experts Group', #PH
+    'JSFT' => 'Jetsoft Development',
+    'JVC ' => 'JVC Information Products Co.',
+    'KART' => 'Scitex Corporation, Ltd.',
+    'Kart' => 'Scitex Corporation, Ltd.',
+    'kart' => 'Scitex Corporation, Ltd.',
+    'KFC ' => 'KFC Computek Components Corporation',
+    'KLH ' => 'KLH Computers',
+    'KMHD' => 'Konica Minolta Holdings, Inc.',
+    'KNCA' => 'Konica Corporation',
+    'KODA' => 'Kodak',
+    'KYOC' => 'Kyocera',
+    'LCAG' => 'Leica Camera AG',
+    'LCCD' => 'Leeds Colour',
+    'lcms' => 'Little CMS', #NealKrawetz
+    'LDAK' => 'Left Dakota',
+    'LEAD' => 'Leading Technology, Inc.',
+    'Leaf' => 'Leaf', #PH
+    'LEXM' => 'Lexmark International, Inc.',
+    'LINK' => 'Link Computer, Inc.',
+    'LINO' => 'Linotronic',
+    'Lino' => 'Linotronic', #PH (NC)
+    'lino' => 'Linotronic', #PH (NC)
+    'LITE' => 'Lite-On, Inc.',
+    'MAGC' => 'Mag Computronic (USA) Inc.',
+    'MAGI' => 'MAG Innovision, Inc.',
+    'MANN' => 'Mannesmann',
+    'MICN' => 'Micron Technology, Inc.',
+    'MICR' => 'Microtek',
+    'MICV' => 'Microvitec, Inc.',
+    'MINO' => 'Minolta',
+    'MITS' => 'Mitsubishi Electronics America, Inc.',
+    'MITs' => 'Mitsuba Corporation',
+    'Mits' => 'Mitsubishi Electric Corporation Kyoto Works',
+    'MNLT' => 'Minolta',
+    'MODG' => 'Modgraph, Inc.',
+    'MONI' => 'Monitronix, Inc.',
+    'MONS' => 'Monaco Systems Inc.',
+    'MORS' => 'Morse Technology, Inc.',
+    'MOTI' => 'Motive Systems',
+    'MSFT' => 'Microsoft Corporation',
+    'MUTO' => 'MUTOH INDUSTRIES LTD.',
+    'NANA' => 'NANAO USA Corporation',
+    'NEC ' => 'NEC Corporation',
+    'NEXP' => 'NexPress Solutions LLC',
+    'NISS' => 'Nissei Sangyo America, Ltd.',
+    'NKON' => 'Nikon Corporation',
+    'ob4d' => 'Erdt Systems GmbH & Co KG',
+    'obic' => 'Medigraph GmbH',
+    'OCE ' => 'Oce Technologies B.V.',
+    'OCEC' => 'OceColor',
+    'OKI ' => 'Oki',
+    'OKID' => 'Okidata',
+    'OKIP' => 'Okidata',
+    'OLIV' => 'Olivetti',
+    'OLYM' => 'OLYMPUS OPTICAL CO., LTD',
+    'ONYX' => 'Onyx Graphics',
+    'OPTI' => 'Optiquest',
+    'PACK' => 'Packard Bell',
+    'PANA' => 'Matsushita Electric Industrial Co., Ltd.',
+    'PANT' => 'Pantone, Inc.',
+    'PBN ' => 'Packard Bell',
+    'PFU ' => 'PFU Limited',
+    'PHIL' => 'Philips Consumer Electronics Co.',
+    'PNTX' => 'HOYA Corporation PENTAX Imaging Systems Division',
+    'POne' => 'Phase One A/S',
+    'PREM' => 'Premier Computer Innovations',
+    'PRIN' => 'Princeton Graphic Systems',
+    'PRIP' => 'Princeton Publishing Labs',
+    'QLUX' => 'Hong Kong',
+    'QMS ' => 'QMS, Inc.',
+    'QPCD' => 'QPcard AB',
+    'QUAD' => 'QuadLaser',
+    'quby' => 'Qubyx Sarl',
+    'QUME' => 'Qume Corporation',
+    'RADI' => 'Radius, Inc.',
+    'RDDx' => 'Integrated Color Solutions, Inc.',
+    'RDG ' => 'Roland DG Corporation',
+    'REDM' => 'REDMS Group, Inc.',
+    'RELI' => 'Relisys',
+    'RGMS' => 'Rolf Gierling Multitools',
+    'RICO' => 'Ricoh Corporation',
+    'RNLD' => 'Edmund Ronald',
+    'ROYA' => 'Royal',
+    'RPC ' => 'Ricoh Printing Systems,Ltd.',
+    'RTL ' => 'Royal Information Electronics Co., Ltd.',
+    'SAMP' => 'Sampo Corporation of America',
+    'SAMS' => 'Samsung, Inc.',
+    'SANT' => 'Jaime Santana Pomares',
+    'SCIT' => 'Scitex Corporation, Ltd.',
+    'Scit' => 'Scitex Corporation, Ltd.',
+    'scit' => 'Scitex Corporation, Ltd.',
+    'SCRN' => 'Dainippon Screen',
+    'scrn' => 'Dainippon Screen',
+    'SDP ' => 'Scitex Corporation, Ltd.',
+    'Sdp ' => 'Scitex Corporation, Ltd.',
+    'sdp ' => 'Scitex Corporation, Ltd.',
+    'SEC ' => 'SAMSUNG ELECTRONICS CO.,LTD',
+    'SEIK' => 'Seiko Instruments U.S.A., Inc.',
+    'SEIk' => 'Seikosha',
+    'SGUY' => 'ScanGuy.com',
+    'SHAR' => 'Sharp Laboratories',
+    'SICC' => 'International Color Consortium',
+    'siwi' => 'SIWI GRAFIKA CORPORATION',
+    'SONY' => 'SONY Corporation',
+    'Sony' => 'Sony Corporation',
+    'SPCL' => 'SpectraCal',
+    'STAR' => 'Star',
+    'STC ' => 'Sampo Technology Corporation',
+    'TALO' => 'Talon Technology Corporation',
+    'TAND' => 'Tandy',
+    'TATU' => 'Tatung Co. of America, Inc.',
+    'TAXA' => 'TAXAN America, Inc.',
+    'TDS ' => 'Tokyo Denshi Sekei K.K.',
+    'TECO' => 'TECO Information Systems, Inc.',
+    'TEGR' => 'Tegra',
+    'TEKT' => 'Tektronix, Inc.',
+    'TI  ' => 'Texas Instruments',
+    'TMKR' => 'TypeMaker Ltd.',
+    'TOSB' => 'TOSHIBA corp.',
+    'TOSH' => 'Toshiba, Inc.',
+    'TOTK' => 'TOTOKU ELECTRIC Co., LTD',
+    'TRIU' => 'Triumph',
+    'TSBT' => 'TOSHIBA TEC CORPORATION',
+    'TTX ' => 'TTX Computer Products, Inc.',
+    'TVM ' => 'TVM Professional Monitor Corporation',
+    'TW  ' => 'TW Casper Corporation',
+    'ULSX' => 'Ulead Systems',
+    'UNIS' => 'Unisys',
+    'UTZF' => 'Utz Fehlau & Sohn',
+    'VARI' => 'Varityper',
+    'VIEW' => 'Viewsonic',
+    'VISL' => 'Visual communication',
+    'VIVO' => 'Vivo Mobile Communication Co., Ltd',
+    'WANG' => 'Wang',
+    'WLBR' => 'Wilbur Imaging',
+    'WTG2' => 'Ware To Go',
+    'WYSE' => 'WYSE Technology',
+    'XERX' => 'Xerox Corporation',
+    'XRIT' => 'X-Rite',
+    'yxym' => 'YxyMaster GmbH',
+    'Z123' => "Lavanya's test Company",
+    'Zebr' => 'Zebra Technologies Inc',
+    'ZRAN' => 'Zoran Corporation',
+    # also seen: "    ",ACMS,KCMS,UCCM,etc2,SCTX
+);
 
 # ICC_Profile tag table
 %Image::ExifTool::ICC_Profile::Main = (
@@ -85,7 +363,7 @@ my %profileClass = (
     },
     targ => {
         Name => 'CharTarget',
-        ValueConv => 'length $val > 128 ? \$val : $val',
+        ValueConv => '$val=~s/\0.*//; length $val > 128 ? \$val : $val',
     },
     chad => 'ChromaticAdaptation',
     chrm => {
@@ -256,6 +534,11 @@ my %profileClass = (
     # Microsoft custom tags (ref http://msdn2.microsoft.com/en-us/library/ms536870.aspx)
     MS00 => 'WCSProfiles',
 
+    psd3 => { #6
+        Name => 'PostScript2CRD3',
+        Binary => 1, # (NC)
+    },
+
     # the following entry represents the ICC profile header, and doesn't
     # exist as a tag in the directory.  It is only in this table to provide
     # a link so ExifTool can locate the header tags
@@ -274,6 +557,8 @@ my %profileClass = (
     4 => {
         Name => 'ProfileCMMType',
         Format => 'string[4]',
+        SeparateTable => 'ManuSig',
+        PrintConv => \%manuSig,
     },
     8 => {
         Name => 'ProfileVersion',
@@ -326,12 +611,13 @@ my %profileClass = (
     48 => {
         Name => 'DeviceManufacturer',
         Format => 'string[4]',
-        # KODA = Kodak
+        SeparateTable => 'ManuSig',
+        PrintConv => \%manuSig,
     },
     52 => {
         Name => 'DeviceModel',
         Format => 'string[4]',
-        # ROMM = Refrence Output Medium Metric
+        # ROMM = Reference Output Medium Metric
     },
     56 => {
         Name => 'DeviceAttributes',
@@ -361,7 +647,8 @@ my %profileClass = (
     80 => {
         Name => 'ProfileCreator',
         Format => 'string[4]',
-        # KODA = Kodak
+        SeparateTable => 'ManuSig',
+        PrintConv => \%manuSig,
     },
     84 => {
         Name => 'ProfileID',
@@ -517,7 +804,7 @@ my %profileClass = (
 );
 
 #------------------------------------------------------------------------------
-# print ICC Profile ID in hex
+# Print ICC Profile ID in hex
 # Inputs: 1) string of numbers
 # Returns: string of hex digits
 sub HexID($)
@@ -532,7 +819,7 @@ sub HexID($)
 }
 
 #------------------------------------------------------------------------------
-# get formatted value from ICC tag (which has the type embedded)
+# Get formatted value from ICC tag (which has the type embedded)
 # Inputs: 0) data reference, 1) offset to tag data, 2) tag data size
 # Returns: Formatted value or undefined if format not supported
 # Notes: The following types are handled by BinaryTables:
@@ -761,7 +1048,7 @@ sub ProcessICC($$)
         return 1;
     }
     $raf->Seek(0, 0);
-    unless ($raf->Read($buff, $size)) {
+    unless ($raf->Read($buff, $size) == $size) {
         $et->Error('Truncated ICC profile');
         return 1;
     }
@@ -893,7 +1180,7 @@ sub ProcessICC_Profile($$$)
                         DataPt => $dataPt,
                         Size   => $strLen,
                         Start  => $valuePtr + $strPos,
-                        Format => "type '$fmt'",
+                        Format => "type '${fmt}'",
                     );
                 }
                 $et->Warn("Corrupted $$tagInfo{Name} data") if $i < $count;
@@ -910,7 +1197,7 @@ sub ProcessICC_Profile($$$)
             DataPt => $dataPt,
             Size   => $size,
             Start  => $valuePtr,
-            Format => "type '$fmt'",
+            Format => "type '${fmt}'",
         );
         if ($subdir) {
             my $name = $$tagInfo{Name};
@@ -977,7 +1264,7 @@ data created on one device into another device's native color space.
 
 =head1 AUTHOR
 
-Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
